:tocdepth: 2

Utilities
=========

.. autofunction:: delb.utils.compare_trees

.. autoclass:: delb.utils.TreesComparisonResult

.. autofunction:: delb.utils.first

.. autofunction:: delb.utils.get_traverser

.. autofunction:: delb.utils.last

.. autofunction:: delb.tag
